@@ -345,7 +345,8 @@ def _check_registry_health(cmd, registry_name, repository, ignore_errors):
     status_validated = _get_registry_status(login_server, registry_name, ignore_errors)
     if status_validated:
         RoleAssignmentMode = cmd.get_models('RoleAssignmentMode')
-        registry_abac_enabled = registry.role_assignment_mode == RoleAssignmentMode.ABAC_REPOSITORY_PERMISSIONS
+        registry_abac_enabled = \
+            registry and registry.role_assignment_mode == RoleAssignmentMode.ABAC_REPOSITORY_PERMISSIONS
         _get_endpoint_and_token_status(cmd, login_server, registry_abac_enabled, repository, ignore_errors)
 
     if cmd.supported_api_version(min_api='2020-11-01-preview', resource_type=ResourceType.MGMT_CONTAINERREGISTRY):  # pylint: disable=too-many-nested-blocks
