@@ -1641,3 +1641,104 @@ helps['containerapp compose create'] = """
               --environment MyContainerappEnv \\
               --compose-file-path "path/to/docker-compose.yml"
 """
+
+# Routing
+helps['containerapp env http-route-config'] = """
+    type: group
+    short-summary: Commands to manage environment level http routing.
+"""
+
+helps['containerapp env http-route-config list'] = """
+    type: command
+    short-summary: List the http route configs in the environment.
+    examples:
+    - name: List the http route configs in the environment.
+      text: |
+          az containerapp env http-route-config list -g MyResourceGroup -n MyEnvironment
+"""
+
+helps['containerapp env http-route-config create'] = """
+    type: command
+    short-summary: Create a new http route config.
+    examples:
+    - name: Create a new route from a yaml file.
+      text: |
+          az containerapp env http-route-config create -g MyResourceGroup -n MyEnvironment -r configname --yaml config.yaml
+"""
+
+helps['containerapp env http-route-config update'] = """
+    type: command
+    short-summary: Update a http route config.
+    examples:
+    - name: Update a route in the environment from a yaml file.
+      text: |
+          az containerapp env http-route-config update -g MyResourceGroup -n MyEnvironment -r configname --yaml config.yaml
+"""
+
+helps['containerapp env http-route-config show'] = """
+    type: command
+    short-summary: Show a http route config.
+    examples:
+    - name: Show a route in the environment.
+      text: |
+          az containerapp env http-route-config show -g MyResourceGroup -n MyEnvironment -r configname
+"""
+
+helps['containerapp env http-route-config delete'] = """
+    type: command
+    short-summary: Delete a http route config.
+    examples:
+    - name: Delete a route from the environment.
+      text: |
+          az containerapp env http-route-config delete -g MyResourceGroup -n MyEnvironment -r configname
+"""
+
+# Ingress
+helps['containerapp env premium-ingress show'] = """
+    type: command
+    short-summary: Show the premium ingress settings for the environment.
+    examples:
+    - name: Show the premium ingress settings for the environment.
+      text: |
+          az containerapp env premium-ingress show -g MyResourceGroup -n MyEnvironment
+"""
+
+helps['containerapp env premium-ingress'] = """
+    type: group
+    short-summary: Configure premium ingress settings for the environment.
+    long-summary: |
+        Premium ingress settings apply to all applications in the environment. They allow moving the ingress instances to a workload profile and scaling them beyond the system defaults to enable high traffic workloads. Other settings include request idle timeouts, header count limits, and the termination grace period.
+    examples:
+    - name: Enable premium ingress for the environment.
+      text: |
+          az containerapp env premium-ingress add -g MyResourceGroup -n MyEnvironment -w WorkloadProfileName
+"""
+
+helps['containerapp env premium-ingress add'] = """
+    type: command
+    short-summary: Enable the premium ingress settings for the environment.
+    long-summary: |
+        Unspecified optional parameters will be cleared from any existing configuration.
+    examples:
+    - name: Add the premium ingress settings for the environment.
+      text: |
+          az containerapp env premium-ingress add -g MyResourceGroup -n MyEnvironment -w WorkloadProfileName
+"""
+
+helps['containerapp env premium-ingress update'] = """
+    type: command
+    short-summary: Update the premium ingress settings for the environment.
+    examples:
+    - name: Update the workload profile used for premium ingress.
+      text: |
+          az containerapp env premium-ingress update -g MyResourceGroup -n MyEnvironment -w WorkloadProfileName
+"""
+
+helps['containerapp env premium-ingress remove'] = """
+    type: command
+    short-summary: Remove the ingress settings and restores the system to default values.
+    examples:
+    - name: Reset the ingress settings for the environment to its default values
+      text: |
+          az containerapp env premium-ingress remove -g MyResourceGroup -n MyEnvironment
+"""
