@@ -23,6 +23,7 @@ from ..aaz.latest.storage.share_rm import Update as _ShareRmUpdate
 from ..aaz.latest.storage.share_rm import Delete as _ShareRmDelete
 from ..aaz.latest.storage.share_rm import Show as _ShareRmShow
 from ..aaz.latest.storage.share_rm import List as _ShareRmList
+from ..util import get_datetime_from_string
 
 logger = get_logger(__name__)
 
@@ -527,17 +528,30 @@ def _file_share_exists(client, resource_group_name, account_name, share_name):
 
 
 # pylint: disable=redefined-builtin
-def generate_sas_file(cmd, client, directory_name=None, file_name=None, permission=None, expiry=None, start=None,
-                      id=None, ip=None, protocol=None, **kwargs):
+def generate_sas_file(cmd, client, share_name=None, directory_name=None, file_name=None, permission=None, expiry=None,
+                      start=None, id=None, ip=None, protocol=None, as_user=False, user_delegation_oid=None, **kwargs):
     t_generate_file_sas = get_sdk(cmd.cli_ctx, ResourceType.DATA_STORAGE_FILESHARE,
                                   '_shared_access_signature#generate_file_sas')
     file_path = file_name
     if directory_name:
         file_path = directory_name + '/' + file_path
     file_path = file_path.split('/')
-    sas_token = t_generate_file_sas(account_name=client.account_name, share_name=client.share_name, file_path=file_path,
-                                    account_key=client.credential.account_key, permission=permission, expiry=expiry,
-                                    start=start, policy_id=id, ip=ip, protocol=protocol, **kwargs)
+
+    account_key = None
+    user_delegation_key = None
+    if as_user:
+        from datetime import datetime
+        user_delegation_key = client.get_user_delegation_key(
+            start=get_datetime_from_string(start) if start else datetime.utcnow(),
+            expiry=get_datetime_from_string(expiry))
+    else:
+        account_key = client.credential.account_key
+
+    sas_token = t_generate_file_sas(account_name=client.account_name, share_name=share_name, file_path=file_path,
+                                    account_key=account_key, permission=permission, expiry=expiry,
+                                    start=start, policy_id=id, ip=ip, protocol=protocol,
+                                    user_delegation_key=user_delegation_key, user_delegation_oid=user_delegation_oid,
+                                    **kwargs)
     from urllib.parse import quote
     return quote(sas_token, safe='&%()$=\',~')
 
