@@ -51,6 +51,8 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         self.feedback = None
         self.extension_management_detail = None
         self.raw_command = None
+        self.command_preserve_casing = None
+        self.is_cmd_idx_rebuild_triggered = False
         self.show_survey_message = False
         self.region_input = None
         self.region_identified = None
@@ -207,6 +209,9 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         set_custom_properties(result, 'InvokeTimeElapsed', str(self.invoke_time_elapsed))
         set_custom_properties(result, 'OutputType', self.output_type)
         set_custom_properties(result, 'RawCommand', self.raw_command)
+        set_custom_properties(result, 'CommandPreserveCasing',
+                              self.command_preserve_casing or '')
+        set_custom_properties(result, 'IsCmdIdxRebuildTriggered', str(self.is_cmd_idx_rebuild_triggered))
         set_custom_properties(result, 'Params', ','.join(self.parameters or []))
         set_custom_properties(result, 'PythonVersion', platform.python_version())
         set_custom_properties(result, 'ModuleCorrelation', self.module_correlation)
@@ -437,12 +442,19 @@ def set_extension_management_detail(ext_name, ext_version):
 
 
 @decorators.suppress_all_exceptions()
-def set_command_details(command, output_type=None, parameters=None, extension_name=None, extension_version=None):
+def set_command_index_rebuild_triggered(is_cmd_idx_rebuild_triggered=False):
+    _session.is_cmd_idx_rebuild_triggered = is_cmd_idx_rebuild_triggered
+
+
+@decorators.suppress_all_exceptions()
+def set_command_details(command, output_type=None, parameters=None, extension_name=None,
+                        extension_version=None, command_preserve_casing=None):
     _session.command = command
     _session.output_type = output_type
     _session.parameters = parameters
     _session.extension_name = extension_name
     _session.extension_version = extension_version
+    _session.command_preserve_casing = command_preserve_casing
 
 
 @decorators.suppress_all_exceptions()
