@@ -644,7 +644,7 @@ def todict(obj, post_processor=None):
     """
     from datetime import date, time, datetime, timedelta
     from enum import Enum
-    from azure.core.serialization import attribute_list
+    from azure.core.serialization import attribute_list, get_backcompat_attr_name
     if isinstance(obj, dict):
         result = {k: todict(v, post_processor) for (k, v) in obj.items()}
         return post_processor(obj, result) if post_processor else result
@@ -662,7 +662,7 @@ def todict(obj, post_processor=None):
     # azure-core provided new function `attribute_list` to list all attribute names
     # so that we don't need to use raw __dict__ directly
     if getattr(obj, "_is_model", False):
-        result = {to_camel_case(attr): todict(getattr(obj, attr), post_processor)
+        result = {to_camel_case(get_backcompat_attr_name(obj, attr)): todict(getattr(obj, attr), post_processor)
                   for attr in attribute_list(obj) if hasattr(obj, attr)}
         return post_processor(obj, result) if post_processor else result
     if hasattr(obj, '_asdict'):
@@ -1164,12 +1164,6 @@ ConfiguredDefaultSetter = ScopedConfig
 
 
 def _ssl_context():
-    if sys.version_info < (3, 4) or (in_cloud_console() and platform.system() == 'Windows'):
-        try:
-            return ssl.SSLContext(ssl.PROTOCOL_TLS)  # added in python 2.7.13 and 3.6
-        except AttributeError:
-            return ssl.SSLContext(ssl.PROTOCOL_TLSv1)
-
     return ssl.create_default_context()
 
 
@@ -1287,6 +1281,19 @@ def roughly_parse_command(args):
     return ' '.join(nouns).lower()
 
 
+def roughly_parse_command_with_casing(args):
+    # Roughly parse the command part: <az VM create> --name vm1
+    # Similar to knack.invocation.CommandInvoker._rudimentary_get_command, but preserves original casing
+    # and we don't need to bother with positional args
+    nouns = []
+    for arg in args:
+        if arg and arg[0] != '-':
+            nouns.append(arg)
+        else:
+            break
+    return ' '.join(nouns)
+
+
 def is_guid(guid):
     import uuid
     try:
